﻿using System;
using System.Configuration;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Transactions;

namespace AdoNetExample
{
	class Program
	{
		static void Main(string[] args)
		{
			Console.ReadLine();
		}

		private static void PrintProducersCount()
		{
			using (var connection = new SqlConnection())
			{
				connection.ConnectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
				connection.Open();

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandText = "SELECT COUNT(*) FROM [Producers]";
					int producerCount = (int)command.ExecuteScalar();
					Console.WriteLine("Producers count: {0}", producerCount);
				}
			}
		}

		private static void PrintProducers()
		{
			using (var connection = new SqlConnection())
			{
				connection.ConnectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
				connection.Open();

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandText = "SELECT [ProducerID], [Name] FROM [Producers]";

					using (DbDataReader reader = command.ExecuteReader())
					{
						while (reader.Read())
						{
							Console.WriteLine("ProducerID: {0}; Name: {1}",
											  reader["ProducerID"],
											  reader["Name"]);
						}
					}
				}
			}
		}

		private static void PrintProducerBrands()
		{
			Console.Write("Input producer ID: ");
			int producerID = Convert.ToInt32(Console.ReadLine());

			using (var connection = new SqlConnection())
			{
				connection.ConnectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
				connection.Open();

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandText =
@"SELECT [BrandID], [Name] FROM [Brands]
  WHERE ([ProducerID] = @producer_id)";
					command.Parameters.AddWithValue("@producer_id", producerID);

					using (DbDataReader reader = command.ExecuteReader())
					{
						while (reader.Read())
						{
							Console.WriteLine("BrandID: {0}; Name: {1}",
											  reader["BrandID"],
											  reader["Name"]);
						}
					}
				}
			}
		}

		private static void PrintBrandByName()
		{
			Console.WriteLine("Input brand name to search for: ");
			string name = Console.ReadLine();

			using (var connection = new SqlConnection())
			{
				connection.ConnectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
				connection.Open();

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandText =
@"SELECT [BrandID], [Name] FROM [Brands]
  WHERE ([Name] = '" + name + "')";

					using (DbDataReader reader = command.ExecuteReader())
					{
						while (reader.Read())
						{
							Console.WriteLine("BrandID: {0}; Name: {1}",
											  reader["BrandID"],
											  reader["Name"]);
						}
					}
				}
			}
		}

		private static void CreateProduct()
		{
			using (var connection = new SqlConnection())
			{
				connection.ConnectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
				connection.Open();

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandType = CommandType.StoredProcedure;
					command.CommandText = "[CreateProduct]";
					command.Parameters.AddWithValue("@vBrandID", 5);
					command.Parameters.AddWithValue("@vName", "Шоколад Milka алпийско мляко");
					command.Parameters.AddWithValue("@vEnergyValue", (decimal)532);
					command.Parameters.AddWithValue("@vProteins", (decimal)6.8);
					command.Parameters.AddWithValue("@vFats", (decimal)29.6);
					command.Parameters.AddWithValue("@vCarbohydrates", (decimal)58);
					command.Parameters.Add("@vProductID", SqlDbType.Int)
						.Direction = ParameterDirection.Output;

					command.ExecuteNonQuery();
					Console.WriteLine("Created product ID: {0}",
									  (int)command.Parameters["@vProductID"].Value);
				}
			}
		}

		private static void CreateProductInTransaction()
		{
			using (var ts = new TransactionScope())
			using (var connection = new SqlConnection())
			{
				connection.ConnectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
				connection.Open();

				int productID;

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandType = CommandType.StoredProcedure;
					command.CommandText = "[CreateProduct]";
					command.Parameters.AddWithValue("@vBrandID", 5);
					command.Parameters.AddWithValue("@vName", "Шоколад Milka лешници");
					command.Parameters.AddWithValue("@vEnergyValue", (decimal)544);
					command.Parameters.AddWithValue("@vProteins", (decimal)7.6);
					command.Parameters.AddWithValue("@vFats", (decimal)32.4);
					command.Parameters.AddWithValue("@vCarbohydrates", (decimal)54);
					command.Parameters.Add("@vProductID", SqlDbType.Int)
						.Direction = ParameterDirection.Output;

					command.ExecuteNonQuery();
					productID = (int)command.Parameters["@vProductID"].Value;
					Console.WriteLine("Created product ID: {0}", productID);
				}

				using (SqlCommand command = connection.CreateCommand())
				{
					command.CommandType = CommandType.StoredProcedure;
					command.CommandText = "[AddProductIngredient]";
					command.Parameters.AddWithValue("@vProductID", productID);
					command.Parameters.AddWithValue("@vIngredientID", 4);
					command.Parameters.AddWithValue("@vAmount", DBNull.Value);

					command.ExecuteNonQuery();
					Console.WriteLine("Ingredient added to product");
				}

				ts.Complete();
			}
		}
	}
}
